#
# spec file for package python-ZODB
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-ZODB
Version:        6.0
Release:        1.2
Summary:        Zope Object Database: object database and persistence
License:        ZPL-2.1
URL:            https://github.com/zopefoundation/ZODB
Source:         https://files.pythonhosted.org/packages/source/Z/ZODB/ZODB-%{version}.tar.gz
BuildRequires:  %{python_module BTrees >= 4.2.0}
BuildRequires:  %{python_module ZConfig}
BuildRequires:  %{python_module manuel}
BuildRequires:  %{python_module persistent-devel >= 4.4.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module transaction >= 2.4.0}
BuildRequires:  %{python_module zc.lockfile}
BuildRequires:  %{python_module zodbpickle >= 1.0.1}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  %{python_module zope.testing}
BuildRequires:  %{python_module zope.testrunner >= 4.4.6}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-BTrees >= 4.2.0
Requires:       python-ZConfig
Requires:       python-persistent >= 4.4.0
Requires:       python-transaction >= 2.4.0
Requires:       python-zc.lockfile
Requires:       python-zodbpickle >= 1.0.1
Requires:       python-zope.interface
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
The Zope Object Database provides an object-oriented database for Python that
provides a high-degree of transparency. Applications can take advantage of
object database features with few, if any, changes to application logic. ZODB
includes features such as a plugable storage interface, rich transaction
support, and undo.

%package     -n %{name}-doc
Summary:        Zope Object Database: object database and persistence
Provides:       %{python_module ZODB-doc = %{version}}

%description -n %{name}-doc
This package contains documentation files for %{name}.

%prep
%setup -q -n ZODB-%{version}
# delete backup files
find . -name "*~" -print -delete
# remove unwanted shebang
find src -name "*.py" | xargs sed -i '1 { /^#!/ d }'
rm -rf src/ZODB.egg-info
# do not test docu generating
rm -f src/ZODB/tests/testdocumentation.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/fsdump
%python_clone -a %{buildroot}%{_bindir}/fsoids
%python_clone -a %{buildroot}%{_bindir}/fsrefs
%python_clone -a %{buildroot}%{_bindir}/fstail
%python_clone -a %{buildroot}%{_bindir}/repozo

mkdir -p %{buildroot}%{_defaultdocdir}/python-ZODB-doc/docs
cp -r docs/* %{buildroot}%{_defaultdocdir}/python-ZODB-doc/docs/
%fdupes %{buildroot}%{_defaultdocdir}/python-ZODB-doc

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} zope-testrunner-%{$python_bin_suffix} --test-path=src

%post
%python_install_alternative fsdump fsoids fsrefs fstail repozo

%postun
%python_uninstall_alternative fsdump

%files %{python_files}
%license LICENSE.txt COPYRIGHT.txt
%doc 3.11.txt CHANGES.rst HISTORY.rst README.rst
%{python_sitelib}/ZODB/
%{python_sitelib}/ZODB-%{version}-py*.egg-info
%python_alternative %{_bindir}/fsdump
%python_alternative %{_bindir}/fsoids
%python_alternative %{_bindir}/fsrefs
%python_alternative %{_bindir}/fstail
%python_alternative %{_bindir}/repozo

%files -n %{name}-doc
%doc %{_defaultdocdir}/python-ZODB-doc

%changelog
* Thu May 30 2024 Markéta Machová <mmachova@suse.com>
- Update to 6.0
  * Add support for Python 3.12.
  * Drop support for Python 2.7, 3.5, 3.6.
  * Fix sorting issue in scripts/space.py.
  * FileStorage: fix a rare data corruption when using restore after multiple undos.
  * Fix exit code of repozo script in case of verification error.
- Fix deduplication of documentation.
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 5.8.1:
  * Fix racetest problems. For details see #376.
  * Fix --with-verify argument in script repozo --recover. For
    details see #381.
* Thu Dec  1 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 5.8.0:
  * Add support for Python 3.11.
  * Expand and refactor tests for race conditions.
* Wed Sep  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Renamed doc dir to docs in spec
* Wed Sep  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 5.7.0:
  * Fix TypeError: can't concat str to bytes when running fsoids.py script with Python 3. See issue 350.
  * Readd transaction size information to fsdump output; adapt fsstats to fsdump's exchanged order for
    size and class information in data records; (fixes #354 <https://github.com/zopefoundation/ZODB/issues/354>_).
    Make ``fsdump` callable via Python's -m command line option.
  * Fix UnboundLocalError when running fsoids.py script. See issue 285.
  * Rework fsrefs script to work significantly faster by optimizing how it does IO. See PR 340.
  * Require Python 3 to build the documentation.
  * Fix deprecation warnings occurring on Python 3.10.
  * Add support for Python 3.9 and 3.10.
* Thu Apr 14 2022 pgajdos@suse.com
- python-mock is not required for build
* Fri Jun 12 2020 Jason Craig <os-dev@jacraig.com>
- Update to 5.6.0:
  * Fix tests with transaction 3.0 (remove patch).
    + transaction3.patch
  * Fix race with invalidations when starting a new transaction.
  * Fix inconsistent resolution order with zope.interface v5.
  * Drop support for Python 3.4.
  * Add support for Python 3.8.
  * See CHANGES.rst for more.
* Mon May  4 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to work with transaction 3.x:
  * transaction3.patch
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.5.1:
  * Add support for Python 3.7.
  * Bump the dependency on zodbpickle to at least 1.0.1. This is required to avoid a memory leak on Python 2.7. See issue 203.
  * Bump the dependency on persistent to at least 4.4.0.
  * Make the internal support functions for dealing with OIDs (p64 and u64) somewhat faster and raise more informative exceptions on certain types of bad input. See issue 216.
  * Remove support for python setup.py test. It hadn't been working for some time. See issue #218.
  * Make the tests run faster by avoiding calls to time.sleep().
- Drop no longer needed python-ZODB-testsuite.patch
* Thu Jul 26 2018 tchvatal@suse.com
- Disable tests for now as 16 of them fail
* Thu Jul 26 2018 tchvatal@suse.com
- Add patch to fix testsuite execution:
  * python-ZODB-testsuite.patch
* Thu Jul 26 2018 tchvatal@suse.com
- Version update to 5.4.0:
  * Dropped support for py3.3 and added support for new ones
  * ZODB now uses pickle protocol 3 for both Python 2 and Python 3.
  * The zodbpickle package provides a zodbpickle.binary string type that should be used in Python 2 to cause binary strings to be saved in a pickle binary format, so they can be loaded correctly in Python 3. Pickle protocol 3 is needed for this to work correctly.
  * Object identifiers in persistent references are saved as zodbpickle.binary strings in Python 2, so that they are loaded correctly in Python 3.
  * If an object is missing from the index while packing a FileStorage, report its full oid.
  * Storage imports are a bit faster.
  * Storages can be important from non-seekable sources, like file-wrapped pipes.
* Fri Aug 25 2017 toddrme2178@gmail.com
- Fix doc package dependencies
* Tue Aug 15 2017 toddrme2178@gmail.com
- Fix doc package dependency problem
* Sat Jul  8 2017 aloisio@gmx.com
- Update to 5.2.4 (see CHANGES.rst)
- Converted to single-spec
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.1.0:
  * Fix registration of custom logging level names ("BLATHER",
    "TRACE). We have been registering them in the wrong order since
    2004. Before Python 3.4, the stdlib logging module masked the
    error by registering them in both directions.
  * Add support for Python 3.4.
- additional changes from version 4.0.1:
  * Fix POSKeyError during transaction.commit when after
    savepoint.rollback. see #16
  * Ensure that the pickler used in PyPy always has a persistent_id
    attribute (inst_persistent_id is not present on the pure-Python
    pickler). (PR #17)
  * Provide better error reporting when trying to load an object on
    a closed connection.
- drop fix-for-upstream-test.patch: fixed upstream
- delete backup files in sources
- remove unwanted shebang in python file
- do not set the executable bit of python files
- pass -q to the test to avoid spamming the build log
* Sat Feb  1 2014 os-dev@jacraig.com
- Add patch to fix test during build.  This is fixed upstream for next release.
- Update old package URL.
- Update to 4.0.0 (minor changes from git commit log):
  * Try invoking parent close() via super(), hoping to squash ResourceWarning.
    Also, avoid shadowing the 'file' builtin / alias with locals.
  * Bend over backward to avoid ResourceWarnings.
  * Use os.pathsep when constructing $PYTHONPATH (fix test failure on Windows).
  * Update to latest 2.2.0 bootstrap.py
  * Correctly quote Windows pathnames
* Sat Aug  3 2013 hpj@urpla.net
- version 4.0.0b3: initial build
